@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
 
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,15 +21,18 @@
 
 class QString;
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class NodeHelper;
 }
 
-namespace GrantleeTheme {
+namespace GrantleeTheme
+{
 class Theme;
 }
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class HeaderStrategy;
 class HeaderStylePrivate;
 
@@ -94,6 +97,7 @@ public:
 
     void setAttachmentHtml(const QString &html);
     Q_REQUIRED_RESULT QString attachmentHtml() const;
+
 private:
     HeaderStylePrivate *const d;
 };
